@@ -125,8 +125,6 @@ void replace_2(ClientInvoker* self,const std::string& absNodePath, const std::st
 
 void order(ClientInvoker* self,const std::string& absNodePath,const std::string& the_order){ self->order(absNodePath,the_order);}
 
-bool query_auto_flush(ClientInvoker* self){  return true; /* func no longer needed */ }
-
 void alters(ClientInvoker* self,
           const bp::list& list,
           const std::string& alterType, /* one of [ add | change | delete | set_flag | clear_flag ] */
@@ -202,9 +200,6 @@ void export_Client()
  	.def("clear_log",        &ClientInvoker::clearLog,                     ClientDoc::clear_log())
  	.def("flush_log",        &ClientInvoker::flushLog,                     ClientDoc::flush_log())
    .def("log_msg",          &ClientInvoker::logMsg,                       ClientDoc::log_msg())
-   .def("query_auto_flush", &query_auto_flush,                            ClientDoc::query_auto_flush())
-   .def("enable_auto_flush",&ClientInvoker::enable_auto_flush,            ClientDoc::enable_auto_flush())
-   .def("disable_auto_flush",&ClientInvoker::disable_auto_flush,          ClientDoc::disable_auto_flush())
  	.def("restart_server",   &ClientInvoker::restartServer,   ClientDoc::restart_server())
 	.def("halt_server",      &ClientInvoker::haltServer,      ClientDoc::halt_server())
 	.def("shutdown_server",  &ClientInvoker::shutdownServer,  ClientDoc::shutdown_server())
