@@ -1,12 +1,11 @@
 //============================================================================
-// Copyright 2009-2018 ECMWF.
+// Copyright 2009-2019 ECMWF.
 // This software is licensed under the terms of the Apache Licence version 2.0
 // which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
 // In applying this licence, ECMWF does not waive the privileges and immunities
 // granted to it by virtue of its status as an intergovernmental organisation
 // nor does it submit to any jurisdiction.
-//
-//=============================================================
+//=============================================================================
 
 #ifndef TIMELINEDATA_HPP
 #define TIMELINEDATA_HPP
@@ -35,13 +34,15 @@ class TimelineItem
 public:
     enum Type {UndeterminedType,ServerType,SuiteType,FamilyType,TaskType};
 
-    TimelineItem() : type_(UndeterminedType) {}
+    TimelineItem() : type_(UndeterminedType), sortIndex_(0), treeIndex_(0) {}
     TimelineItem(const std::string& path,unsigned char status,unsigned int time,Type type=UndeterminedType);
     size_t size() const {return status_.size();}
     const std::string& path() const {return path_;}
     Type type() const {return type_;}
     void setType(Type t) {type_ = t;}
     size_t sortIndex() const {return sortIndex_;}
+    size_t treeIndex() const {return treeIndex_;}
+    void setTreeIndex(size_t t) {treeIndex_=t;}
     bool isTask() const {return type_ ==  TaskType;}
     void add(unsigned char status,unsigned int time);
     int firstInPeriod(QDateTime startDt,QDateTime endDt) const;
@@ -69,8 +70,11 @@ public:
     std::string path_;
     Type type_;
     size_t sortIndex_;
+    size_t treeIndex_;
+    size_t parentIndex_;
     std::vector<unsigned int> start_;
     std::vector<unsigned char> status_;
+
 };
 
 class TimelineData : public QObject
@@ -83,6 +87,8 @@ public:
         startTime_(0), endTime_(0), maxReadSize_(0), fullRead_(false), loadStatus_(LoadNotTried) {}
 
     void loadLogFile(const std::string& logFile,size_t maxReadSize,const std::vector<std::string>& suites);
+    void loadMultiLogFile(const std::string& logFile,const std::vector<std::string>& suites,int logFileIndex, bool last);
+
     QDateTime loadedAt() const {return loadedAt_;}
     size_t size() const {return  items_.size();}
     const std::vector<TimelineItem>& items() const {return items_;}
@@ -92,21 +98,24 @@ public:
     QDateTime qEndTime() const {return TimelineItem::toQDateTime(endTime_);}
     void clear();    
     void setItemType(int index,TimelineItem::Type type);
+    void setItemTreeIndex(size_t index,size_t treeIndex);
     bool isFullRead() const {return fullRead_;}
     LoadStatus loadStatus() const {return loadStatus_;}
+    void markAsLoadDone() {loadStatus_ = LoadDone;}
     bool indexOfItem(const std::string&,size_t&);
+    const std::vector<size_t>& sortIndex() const {return sortIndex_;}
+
+    static bool parseLine(const std::string& line,std::string& name,
+                          unsigned char& statusId,unsigned int& statusTime);
 
 Q_SIGNALS:
     void loadProgress(size_t current,size_t total);
 
 protected:
+    void loadLogFileCore(const std::string& logFile,size_t maxReadSize,const std::vector<std::string>& suites, bool multi);
     void guessNodeType();
-    TimelineItem::Type guessNodeType(const std::string& line,const std::string& name,
-                                      const std::string& status,
-                                      std::string::size_type next_ws) const;
-    TimelineItem::Type guessNodeType(const std::string& line,
-                                      const std::string& status,
-                                      std::string::size_type next_ws) const;
+    TimelineItem::Type guessNodeType(const std::string& line,const std::string& name) const;
+    TimelineItem::Type guessNodeType(const std::string& line) const;
     void sortByPath();
 
     std::vector<TimelineItem> items_;
@@ -118,7 +127,7 @@ protected:
     bool fullRead_;
     LoadStatus loadStatus_;
     QHash<QString,size_t> pathHash_;
+    std::vector<size_t> sortIndex_;
 };
 
-
 #endif // TIMELINEDATA_HPP
