@@ -13,6 +13,7 @@
 #include <QAbstractItemModel>
 
 #include "AbstractNodeModel.hpp"
+#include "ConnectState.hpp"
 #include "Node.hpp"
 #include "VAttributeType.hpp"
 #include "Viewer.hpp"
@@ -126,6 +127,8 @@ private:
     QVariant nodeData(const QModelIndex& index,int role,VTreeNode*) const;
     QVariant attributesData(const QModelIndex& index,int role,VTreeNode*) const;
 
+    int serverConnectId(ConnectState::State st) const;
+
 	//Attribute filter
 	VTreeModelData* data_;
 	AttributeFilter* atts_;
