@@ -484,6 +484,18 @@ void VNode::collect(std::vector<VNode*>& vec) const
 	}
 }
 
+void VNode::collectAborted(std::vector<VNode*>& vec) const
+{
+    for(int i=0; i < numOfChildren(); i++)
+    {
+        if(children_[i]->isAborted())
+        {
+            vec.push_back(children_[i]);
+        }
+        children_[i]->collect(vec);
+    }
+}
+
 int VNode::tryNo() const
 {
 	std::string v=genVariable("ECF_TRYNO");
@@ -1864,7 +1876,13 @@ QString VServer::toolTip()
 		{			
 			txt+="<b><font color=" + colErr.name() +">Server is disconnected!</b><br>";
 			txt+="<b>Disconnected</b>: " + VFileInfo::formatDateAgo(st->lastDisconnectTime()) + "<br>";
-		}
+        }
+        else if(st->state() == ConnectState::Incompatible)
+        {
+            txt+="<b><font color=" + colErr.name() +">Server version is incompatible with client!</b><br>";
+            if(!st->errorMessage().empty())
+                txt+="<b>Error message</b>:<br>" + QString::fromStdString(st->errorMessage());
+        }
 	}
 	return txt;
 }
