@@ -13,11 +13,12 @@ umask 0022
 # ====================================================================
 show_error_and_exit() {
    echo "cmake.sh expects at least one argument"
-   echo " cmake.sh debug || release [clang] [san] [make] [verbose] [test] [stest] [no_gui] [package_source] [debug]"
+   echo " cmake.sh [ options] "
    echo ""
+   echo "   debug          - make a DEBUG build"
    echo "   make           - run make after cmake"
    echo "   ecbuild        - Use git cloned ecbuild over the module loaded ecbuild(default)"
-   echo "   install        - install to /usr/local/apps/eflow.  defaults is /var/tmp/$USER/install/cmake/ecflow"
+   echo "   sys_install    - install to /usr/local/apps/ecflow/<version>  defaults is /var/tmp/$USER/install/cmake/ecflow/<version>"
    echo "   test           - run all the tests"
    echo "   test_safe      - only run deterministic tests"
    echo "   ctest          - all ctest -R <test> -V"
@@ -33,12 +34,13 @@ show_error_and_exit() {
    echo "   package_source - produces ecFlow-<version>-Source.tar.gz file, for users"
    echo "                    copies the tar file to $SCRATCH"
    echo "   copy_tarball   - copies ecFlow-<version>-Source.tar.gz to /tmp/$USER/tmp/. and untars file"
-   echo "\nTo Build with system boost, just call:"
-   echo " 'module load boost/1.53.0' "
-   echo "first"
+   echo ""
+   echo "For a system install"
+   echo "./cmake.sh sys_install make -j8 install"
    exit 1
 }
 
+sys_install=
 ecbuild_arg=
 copy_tarball_arg=
 package_source_arg=
@@ -79,9 +81,10 @@ while [[ "$#" != 0 ]] ; do
          shift
       done
       break
-   elif [[ "$1" = no_gui ]] ; then no_gui_arg=$1 ;
-   elif [[ "$1" = ssl ]]   ; then ssl_arg=$1 ;
-   elif [[ "$1" = secure_user ]]   ; then secure_user_arg=$1 ;
+   elif [[ "$1" = no_gui ]] ;      then no_gui_arg=$1 ;
+   elif [[ "$1" = ssl ]]   ;       then ssl_arg=$1 ;
+   elif [[ "$1" = sys_install ]] ; then sys_install=$1 ;
+   elif [[ "$1" = secure_user ]] ; then secure_user_arg=$1 ;
    elif [[ "$1" = ecbuild ]] ; then ecbuild_arg=$1 ;
    elif [[ "$1" = log ]]   ; then log_arg=$1 ;
    elif [[ "$1" = clang ]] ; then clang_arg=$1 ;
@@ -135,27 +138,17 @@ set -o pipefail # fail if last(rightmost) command exits with a non-zero status
 #
 CXX_FLAGS="-Wno-unused-local-typedefs -Wno-unused-variable -Wno-deprecated-declarations -Wno-address"
  
+
 # ==================== modules ================================================
 # To load module automatically requires Korn shell, system start scripts
-
-module load ecbuild/new
-module load boost/1.53.0     # uncomment to use local BOOST_ROOT
-module load python3/3.6.5-01
-module load cmake/3.12.0    # need cmake 3.12.0 to build python3. Allow boost python 2 and 3 libs to be found  
-# To build python3 when cmake < 3.12.0 use
-# -DPYTHON_EXECUTABLE=/usr/local/apps/python3/%PYTHON3_VERSION%/bin/python3 
-
-
+#
 cmake_extra_options=""
-cmake_extra_options="-DBOOST_ROOT=$BOOST_ROOT "
 if [[ "$clang_arg" = clang || "$clang_tidy_arg" = clang_tidy ]] ; then
-    # ecflow fails to write boost ser' files with clang 6.0.1, but in debug all tests pass
+    # ecflow fails to write boost ser' files with clang 6.0.1/7.0.1, but in debug all tests pass
     # Had to apply fix: http://clang-developers.42468.n3.nabble.com/boost-serialization-crash-with-clang-5-0-0-td4058283.html
     # - still have other crashes n serilisation see: ECFLOW-1328
     module unload gnu
-    module unload clang
-    module load clang/6.0.1
-    cmake_extra_options="-DBOOST_ROOT=/var/tmp/ma0/boost/clang-6.0.1/boost_1_53_0"
+    module load clang/7.0.1
     CXX_FLAGS=""
     CXX_FLAGS="$CXX_FLAGS -Wno-deprecated-declarations -Wno-deprecated-register -Wno-expansion-to-defined"
 
@@ -164,6 +157,14 @@ if [[ "$clang_arg" = clang || "$clang_tidy_arg" = clang_tidy ]] ; then
 	fi
 fi
 
+module load ecbuild/new
+module load boost/1.53.0     # uncomment to use local BOOST_ROOT  may need -DBOOST_ROOT=$BOOST_ROOT 
+module load python3/3.6.5-01
+module load cmake/3.12.0    # need cmake 3.12.0 to build python3. Allow boost python 2 and 3 libs to be found  
+# To build python3 when cmake < 3.12.0 use
+# -DPYTHON_EXECUTABLE=/usr/local/apps/python3/%PYTHON3_VERSION%/bin/python3 
+
+
 # ==============================================================================================
 # sanitisers
 if [[ "$tsan_arg" = tsan && "$asan_arg" = asan ]] ; then
@@ -319,6 +320,9 @@ if [[ $package_source_arg = package_source ]] ; then
 fi
 
 install_prefix=/var/tmp/$USER/install/cmake/ecflow/$release.$major.$minor
+if [[ $sys_install = sys_install ]] ; then
+   install_prefix=/usr/local/apps/ecflow/$release.$major.$minor
+fi
 
 ecbuild=ecbuild
 if [[ $ecbuild_arg = ecbuild ]] ; then
